@@ -1,7 +1,7 @@
 package Perinci::Sub::Wrapper;
 
-our $DATE = '2016-01-20'; # DATE
-our $VERSION = '0.80'; # VERSION
+our $DATE = '2016-01-22'; # DATE
+our $VERSION = '0.81'; # VERSION
 
 use 5.010001;
 use strict;
@@ -956,7 +956,7 @@ sub handle_result {
             $self->push_lines('my $rec_err;');
             $cd->{result} =~ s/\A\s+//;
             $self->push_lines("$cd->{result};");
-            $self->push_lines('if ($rec_err) { die "BUG: Result stream record #$i fail validation: $rec_err" }');
+            $self->push_lines('if ($rec_err) { die "BUG: Result stream record #$i ($rec) fails validation: $rec_err" }');
             $self->push_lines('$rec;');
             $self->unindent;
             $self->push_lines('}; ## result coderef wrapper');
@@ -1476,7 +1476,7 @@ Perinci::Sub::Wrapper - A multi-purpose subroutine wrapping framework
 
 =head1 VERSION
 
-This document describes version 0.80 of Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2016-01-20.
+This document describes version 0.81 of Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2016-01-22.
 
 =head1 SYNOPSIS
 
